@@ -546,11 +546,16 @@ void create_file_dialog (      GtkWidget **dialog,
     g_autoptr(GFile) menu_folder = g_file_new_for_path (menu_folder_str);
     GtkFileFilter *file_filter;
 
-    *dialog = gtk_file_chooser_dialog_new ((open) ? _("Open Openbox Menu File") : _("Save Openbox Menu File As…"), 
+    // Translation note: the verb "Open"
+    *dialog = gtk_file_chooser_dialog_new ((open) ? _("Open Openbox Menu File") : 
+	                                                _("Save Openbox Menu File As…"), 
                                            GTK_WINDOW (ks.window),
                                            (open) ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE, 
                                            C_("Cancel|File Dialogue", "_Cancel"), GTK_RESPONSE_CANCEL,
-                                           (open) ? _("_Open") : _("_Save"), GTK_RESPONSE_ACCEPT,
+										   // Translation note: the verb "Open"
+                                           (open) ? _("_Open") :
+										   // Translation note: the verb "Save"
+            										_("_Save"), GTK_RESPONSE_ACCEPT,
                                            NULL);
 
     if (g_file_query_exists (menu_folder, NULL)) {
@@ -619,7 +624,9 @@ void determine_theme_type (void)
         g_string_printf (ks.mandatory_label_txt, "(<span foreground='%s'>*</span>) = %s", ks.red_hue, _("mandatory"));
         g_string_printf (ks.mandatory_empty_string_txt, "(<span foreground='%s'>*</span>) = %s; "
                                                         "(<span foreground='%s'>*</span>) = %s",
-                                                        ks.red_hue, _("mandatory"), ks.blue_hue, _("mand. as empty-string menu ID exists"));
+                                                        ks.red_hue, _("mandatory"), 
+														// Translation note: "mand. as" means "mandatory because" here 
+														ks.blue_hue, _("mand. as empty-string menu ID exists"));
         g_string_printf (ks.double_menu_id_label_txt, " <span foreground='%s'>!!</span> %s <span foreground='%s'>!!</span> ", 
                                                       ks.red_hue,  _("Menu ID already exists "), ks.red_hue);
     }
