@@ -1,7 +1,7 @@
 /*
    Kickshaw - A Menu Editor for Openbox
 
-   Copyright (c) 2010–2022        Marcus Schätzle
+   Copyright (c) 2010–2024        Marcus Schätzle
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -46,14 +46,21 @@ static gboolean write_row_information (GtkTreeModel  *model,
 static void show_errmsg_and_restore_position_index (const gchar  *action, 
                                                           GError *error)
 {
-    g_autofree gchar *err_msg = g_strdup_printf ("<b>%s undo stack item</b> <tt>%i</tt> "
-                                                 "<b>inside tmp folder</b> <tt>%s</tt> <b>!"
-                                                 "\nError:</b> %s", 
-                                                 (STREQ (action, "creation")) ? 
-                                                 "Could not create" : 
-                                                 ((STREQ (action, "writing")) ?
-                                                 "An error occurred during the writing process of the new" :
-                                                 "Could not remove incomplete"), 
+    const gchar *err_msg_markup;
+
+    if (STREQ (action, "creation")) {
+        err_msg_markup = _("<b>Could not create undo stack item</b> <tt>%1$i</tt> <b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s");
+    }
+    else if (STREQ (action, "writing")) {
+        err_msg_markup = _("<b>An error occurred during the writing process of the new undo stack item</b> "
+                           "<tt>%1$i</tt> <b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s");
+    }
+    else { // deletion
+        err_msg_markup = _("<b>Could not remove incomplete undo stack item</b> "
+                           "<tt>%1$i</tt> <b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s");
+    }
+
+    g_autofree gchar *err_msg = g_strdup_printf (err_msg_markup, 
                                                  (!STREQ (action, "deletion")) ? ks.pos_inside_undo_stack-- : ks.pos_inside_undo_stack, 
                                                  ks.tmp_path, error->message);
 
@@ -87,7 +94,7 @@ static gboolean write_row_information (GtkTreeModel  *model,
     for (guint8 tree_store_loop = 0; tree_store_loop < NUMBER_OF_TXT_FIELDS; ++tree_store_loop) {
         /*
             Reading of the tree store data has to start from TS_ICON_PATH,
-            since TS_ICON_IMG, TS_ICON_IMG_STATUS and TS_ICON_MODIFICATION_TIME aren't used.
+            since TS_ICON_IMG, TS_ICON_IMG_STATUS, and TS_ICON_MODIFICATION_TIME aren't used.
         */
         gtk_tree_model_get (model, iter, tree_store_loop + TS_ICON_PATH, &undo_txt_fields[tree_store_loop], -1);
         g_string_append_printf (row_info, "%s%c", 
@@ -139,15 +146,15 @@ void push_new_item_on_undo_stack (const gboolean after_save)
             g_autoptr(GFile) later_undo_file = g_file_new_for_path (later_undo_file_str);
 
             if (G_UNLIKELY (!(g_file_delete (later_undo_file, NULL, &error)))) {
-                g_autofree gchar *err_msg = g_strdup_printf ("<b>Could not remove undo stack item</b> <tt>%i</tt> "
-                                                             "<b>inside tmp folder</b> <tt>%s</tt> <b>!\nError:</b> %s\n\n"
-                                                             "--- Note ---\n\n"
-                                                             "All undo stack items after the current position are supposed "
-                                                             "to be deleted when a change is applied prior to the latest change, "
-                                                             "i.e. when it is applied from a position within the undo stack.\n"
-                                                             "A new undo stack item '<tt>%i</tt>' for this change won't be saved "
-                                                             "so it will not be possible to recall this change by invoking an "
-                                                             "undo or redo action.", 
+                g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not remove undo stack item</b> <tt>%1$i</tt> "
+                                                               "<b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s\n\n"
+                                                               "--- Note ---\n\n"
+                                                               "All undo stack items after the current position are supposed "
+                                                               "to be deleted when a change is applied prior to the latest change, "
+                                                               "i.e. when it is applied from a position within the undo stack.\n"
+                                                               "A new undo stack item '<tt>%4$i</tt>' for this change won't be saved "
+                                                               "so it will not be possible to recall this change by invoking an "
+                                                               "undo or redo action."), 
                                                              stack_file_cnt, ks.tmp_path, error->message, ks.pos_inside_undo_stack + 1);
 
                 show_errmsg (err_msg);
@@ -179,8 +186,8 @@ void push_new_item_on_undo_stack (const gboolean after_save)
     else {
         if (G_UNLIKELY (!((undo_file_output_stream = G_OUTPUT_STREAM (g_file_replace (compressed_undo_file, NULL, FALSE, 
                                                                                       G_FILE_CREATE_NONE, NULL, &error)))))) {
-            g_autofree gchar *err_msg = g_strdup_printf ("<b>Could not remove undo stack item</b> <tt>%i</tt> "
-                                                         "<b>inside tmp folder</b> <tt>%s</tt> <b>!\nError:</b> %s", 
+            g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not remove undo stack item</b> <tt>%1$i</tt> "
+                                                           "<b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s"), 
                                                          ks.pos_inside_undo_stack, ks.tmp_path, error->message);
 
             show_errmsg (err_msg);
@@ -249,7 +256,7 @@ void undo_redo_restore (const gchar *action)
     const gint new_pos_inside_undo_stack = (STREQ (action, "undo")) ? ks.pos_inside_undo_stack - 1 : ks.pos_inside_undo_stack + 1;
     g_autofree gchar *compressed_undo_file_str = (!(STREQ (action, "restore"))) ? 
                                                  g_strdup_printf ("%s/%i", ks.tmp_path, new_pos_inside_undo_stack) : 
-                                                 g_build_filename (g_get_home_dir (), ".kickshaw_autosave", NULL);
+                                                 g_build_filename (ks.home_dir, ".kickshaw_autosave", NULL);
     g_autoptr(GFile) compressed_undo_file = g_file_new_for_path (compressed_undo_file_str);
     g_autoptr(GFileInputStream) undo_file_input_stream;
     g_autoptr(GError) error = NULL;
@@ -258,12 +265,13 @@ void undo_redo_restore (const gchar *action)
         g_autofree gchar *err_msg;
 
         if (!(STREQ (action, "restore"))) {
-            err_msg = g_strdup_printf ("<b>Could not open undo stack item</b> <tt>%i</tt> "
-                                       "<b>inside tmp folder</b> <tt>%s</tt> <b>for reading!\n"
-                                       "Error:</b> %s", new_pos_inside_undo_stack, ks.tmp_path, error->message);
+            err_msg = g_strdup_printf (_("<b>Could not open undo stack item</b> <tt>%1$i</tt> "
+                                         "<b>inside tmp folder</b> <tt>%2$s</tt> <b>for reading!\n"
+                                         "Error:</b> %3$s"), 
+                                       new_pos_inside_undo_stack, ks.tmp_path, error->message);
         }
         else {
-            err_msg = g_strdup_printf ("<b>Could not open autosave file</b> <tt>%s</tt> <b>!\nError:</b> %s", 
+            err_msg = g_strdup_printf (_("<b>Could not open autosave file</b> <tt>%s</tt> <b>!\nError:</b> %s"), 
                                        compressed_undo_file_str, error->message);
         }
 
@@ -304,7 +312,7 @@ void undo_redo_restore (const gchar *action)
                                                                                          decompressor);
 
     g_autoptr(GString) record = g_string_new (NULL);
-    gchar buffer[1];
+    gchar buffer[2];
 
     // The fields that are stored inside an undo file.
     enum { UN_ICON_PATH, UN_MENU_ELEMENT, UN_TYPE, UN_VALUE, UN_MENU_ID, UN_EXECUTE, UN_ELEMENT_VISIBILITY, 
@@ -336,10 +344,10 @@ void undo_redo_restore (const gchar *action)
         }
         else {
             if (!ks.settings.use_header_bar) {
-                gtk_window_set_title (GTK_WINDOW (ks.window), "Unsaved menu");
+                gtk_window_set_title (GTK_WINDOW (ks.window), _("Unsaved Menu"));
             }
             else {
-                gtk_label_set_label (GTK_LABEL (ks.basename_label), "Unsaved Menu");
+                gtk_label_set_label (GTK_LABEL (ks.basename_label), _("Unsaved Menu"));
                 gtk_widget_hide (ks.subtitle_label);
             }
         }
@@ -378,7 +386,7 @@ void undo_redo_restore (const gchar *action)
                 gtk_tree_store_set (ks.treestore, &iters[iter_idx], tokens_cnt + TS_ICON_PATH, 
                                     (!STREQ (tokens[tokens_cnt], "\0")) ? tokens[tokens_cnt] : 
                                      /*
-                                        Menus, items and separators may have empty labels or no labels at all.
+                                        Menus, items, and separators may have empty labels or no labels at all.
                                         Menu IDs may consist of empty strings.
                                      */
                                      (((tokens_cnt == UN_MENU_ELEMENT && STREQ (tokens[UN_MENU_ITEM_OR_SEP_WITH_LABEL], "TRUE")) ||
@@ -456,12 +464,13 @@ void undo_redo_restore (const gchar *action)
         g_autofree gchar *err_msg;
 
         if (!STREQ (action, "restore")) {
-            err_msg = g_strdup_printf ("<b>Could not read data from undo stack item</b> <tt>%i</tt> "
-                                       "<b>inside tmp folder</b> <tt>%s</tt> <b>!\n"
-                                       "Error:</b> %s", new_pos_inside_undo_stack, ks.tmp_path, error->message);
+            err_msg = g_strdup_printf (_("<b>Could not read data from undo stack item</b> <tt>%1$i</tt> "
+                                         "<b>inside tmp folder</b> <tt>%2$s</tt> <b>!\n"
+                                         "Error:</b> %3$s"), 
+                                       new_pos_inside_undo_stack, ks.tmp_path, error->message);
         }
         else {
-            err_msg = g_strdup_printf ("<b>Could not read data from autosave file</b> <tt>%s</tt> <b>!\nError:</b> %s", 
+            err_msg = g_strdup_printf (_("<b>Could not read data from autosave file</b> <tt>%s</tt> <b>!\nError:</b> %s"), 
                                        compressed_undo_file_str, error->message);
         }
 
@@ -514,8 +523,9 @@ static void update_pos_inside_undo_stack_pointer (void)
     }
 
     if (G_UNLIKELY (error)) {
-        g_autofree gchar *err_msg = g_strdup_printf ("<b>Could not delete symbolic link to undo stack file</b> <tt>%s</tt> <b>!\n"
-                                                     "Error:</b> %s", pos_inside_undo_stack_path, error->message);
+        g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not delete symbolic link to undo stack file</b> <tt>%s</tt> <b>!\n"
+                                                       "Error:</b> %s"), 
+                                                     pos_inside_undo_stack_path, error->message);
 
         show_errmsg (err_msg);
 
@@ -523,8 +533,9 @@ static void update_pos_inside_undo_stack_pointer (void)
     }
 
     if (G_UNLIKELY (!(g_file_make_symbolic_link (symlink_pos_inside_undo_stack, pos_inside_undo_stack_path, NULL, &error)))) {
-        g_autofree gchar *err_msg = g_strdup_printf ("<b>Could not create symbolic link to undo stack file</b> <tt>%s</tt> <b>!\n"
-                                                     "Error:</b> %s", pos_inside_undo_stack_path, error->message);
+        g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not create symbolic link to undo stack file</b> <tt>%s</tt> <b>!\n"
+                                                       "Error:</b> %s"), 
+                                                     pos_inside_undo_stack_path, error->message);
 
         show_errmsg (err_msg);
     }
@@ -538,7 +549,7 @@ static void update_pos_inside_undo_stack_pointer (void)
 
 void write_autosave (GFile *compressed_undo_file)
 {
-    g_autofree gchar *autosave_file_path = g_build_filename (g_get_home_dir (), ".kickshaw_autosave", NULL);
+    g_autofree gchar *autosave_file_path = g_build_filename (ks.home_dir, ".kickshaw_autosave", NULL);
     g_autoptr(GFile) autosave_file = g_file_new_for_path (autosave_file_path);
 
     g_file_copy_async (compressed_undo_file, autosave_file, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, 
@@ -560,8 +571,8 @@ static void write_autosave_callback (      GObject      *source_object,
     g_file_copy_finish ((GFile *) source_object, result, &error);
 
     if (G_UNLIKELY (error)) {
-        g_autofree gchar *err_msg = g_strdup_printf ("<b>Could not create the autosave file</b> <tt>%s</tt> <b>!\nError:</b> %s", 
-                                                      autosave_file_path, error->message);
+        g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not create the autosave file</b> <tt>%s</tt> <b>!\nError:</b> %s"), 
+                                                       autosave_file_path, error->message);
 
         show_errmsg (err_msg);
     }
